domed playground

packages = ["domed"] from domed.core import * from domed.html import * from domed.svg import *

# domed playground Here, you can experiment with different domed expressions, and see the effects directly. All of the domed sublibraries have been preloaded. Here is an example to get you started:

                    with document.query("#content").clear():
                        h1("Hello, world!", style = "color: red;")

Type in expressions below. To evaluate, use shift + return or press the green arrow button.

Change me by typing in commands above.